==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/remove/flow/input/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.remove.flow.input.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.decap.grouping.NxDecap;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxActionDecapRpcRemoveFlowWriteActionsCaseBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder
 * @see Builder
 *
 */
public class NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder implements Builder<NxActionDecapRpcRemoveFlowWriteActionsCase> {

    private NxDecap _nxDecap;


    Map<Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>>, Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> augmentation = Collections.emptyMap();

    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder() {
    }
    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping arg) {
        this._nxDecap = arg.getNxDecap();
    }

    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder(NxActionDecapRpcRemoveFlowWriteActionsCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>>, Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> aug =((AugmentationHolder<NxActionDecapRpcRemoveFlowWriteActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxDecap = base.getNxDecap();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping) {
            this._nxDecap = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping)arg).getNxDecap();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping]");
    }

    public NxDecap getNxDecap() {
        return _nxDecap;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder setNxDecap(final NxDecap value) {
        this._nxDecap = value;
        return this;
    }
    
    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> augmentationType, Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionDecapRpcRemoveFlowWriteActionsCase build() {
        return new NxActionDecapRpcRemoveFlowWriteActionsCaseImpl(this);
    }

    private static final class NxActionDecapRpcRemoveFlowWriteActionsCaseImpl
        extends AbstractAugmentable<NxActionDecapRpcRemoveFlowWriteActionsCase>
        implements NxActionDecapRpcRemoveFlowWriteActionsCase {
    
        private final NxDecap _nxDecap;
    
        NxActionDecapRpcRemoveFlowWriteActionsCaseImpl(NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder base) {
            super(base.augmentation);
            this._nxDecap = base.getNxDecap();
        }
    
        @Override
        public Class<NxActionDecapRpcRemoveFlowWriteActionsCase> getImplementedInterface() {
            return NxActionDecapRpcRemoveFlowWriteActionsCase.class;
        }
    
        @Override
        public NxDecap getNxDecap() {
            return _nxDecap;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxDecap);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionDecapRpcRemoveFlowWriteActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionDecapRpcRemoveFlowWriteActionsCase other = (NxActionDecapRpcRemoveFlowWriteActionsCase)obj;
            if (!Objects.equals(_nxDecap, other.getNxDecap())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionDecapRpcRemoveFlowWriteActionsCaseImpl otherImpl = (NxActionDecapRpcRemoveFlowWriteActionsCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>>, Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionDecapRpcRemoveFlowWriteActionsCase");
            CodeHelpers.appendValue(helper, "_nxDecap", _nxDecap);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.9.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/remove/flow/input/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.remove.flow.input.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.decap.grouping.NxDecap;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder} instances.
 *
 * @see NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder
 *
 */
public class NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder implements Builder<NxActionDecapRpcRemoveFlowWriteActionsCase> {

    private NxDecap _nxDecap;


    Map<Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>>, Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> augmentation = Collections.emptyMap();

    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder() {
    }
    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping arg) {
        this._nxDecap = arg.getNxDecap();
    }

    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder(NxActionDecapRpcRemoveFlowWriteActionsCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>>, Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> aug =((AugmentationHolder<NxActionDecapRpcRemoveFlowWriteActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxDecap = base.getNxDecap();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping) {
            this._nxDecap = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping)arg).getNxDecap();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping]");
    }

    public NxDecap getNxDecap() {
        return _nxDecap;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder setNxDecap(final NxDecap value) {
        this._nxDecap = value;
        return this;
    }
    
    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> augmentationType, Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionDecapRpcRemoveFlowWriteActionsCase build() {
        return new NxActionDecapRpcRemoveFlowWriteActionsCaseImpl(this);
    }

    private static final class NxActionDecapRpcRemoveFlowWriteActionsCaseImpl
        extends AbstractAugmentable<NxActionDecapRpcRemoveFlowWriteActionsCase>
        implements NxActionDecapRpcRemoveFlowWriteActionsCase {
    
        private final NxDecap _nxDecap;
    
        NxActionDecapRpcRemoveFlowWriteActionsCaseImpl(NxActionDecapRpcRemoveFlowWriteActionsCaseBuilder base) {
            super(base.augmentation);
            this._nxDecap = base.getNxDecap();
        }
    
        @Override
        public NxDecap getNxDecap() {
            return _nxDecap;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxDecap);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionDecapRpcRemoveFlowWriteActionsCase.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxActionDecapRpcRemoveFlowWriteActionsCase other = (NxActionDecapRpcRemoveFlowWriteActionsCase)obj;
            if (!Objects.equals(_nxDecap, other.getNxDecap())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionDecapRpcRemoveFlowWriteActionsCaseImpl otherImpl = (NxActionDecapRpcRemoveFlowWriteActionsCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>>, Augmentation<NxActionDecapRpcRemoveFlowWriteActionsCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionDecapRpcRemoveFlowWriteActionsCase");
            CodeHelpers.appendValue(helper, "_nxDecap", _nxDecap);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
